@@ -4,6 +4,7 @@
 #' It just requires an input DTM and at least two point locations ('SpatialPointsDataFrame' class) representing the locations between which the corridor is calculated.
 #' Under the hood, 'movecorr()' relies on the \code{\link{movecost}} function and, needless to say, implements the same
 #' cost functions. See the help documentation of 'movecost()' for further details.\cr
+#' Visit this \href{https://drive.google.com/file/d/1gLDrkZFh1b_glzCEqKdkPrer72JJ9Ffa/view?usp=sharing}{LINK} to access the package's vignette.\cr
 #'
 #' If only two locations are provided (one via parameter 'a', one via parameter 'b'),
 #' the function renders a raster representing the least cost corridor (which can be optionally exported as GeoTiff) with least-cost paths superimposed.
@@ -64,6 +65,7 @@
 #' @param lab.b string to be used to label point a on the outplut plot (B is the default).
 #' @param cex.labs scaling factor for the size of the points' labels (0.8 by default)
 #' @param studyplot polygon (SpatialPolygonDataFrame class) representing the study area for which online elevation data are aquired (see \code{\link{movecost}}); NULL is default.
+#' @param barrier area where the movement is inhibited (SpatialLineDataFrame or SpatialPolygonDataFrame class) (see \code{\link{movecost}}.
 #' @param funct cost function to be used (for details on each of the following, see \code{\link{movecost}}):\cr
 #'
 #' \strong{-functions expressing cost as walking time-}\cr
@@ -87,6 +89,7 @@
 #' \strong{-functions expressing abstract cost-}\cr
 #' \strong{ree} uses the relative energetic expenditure cost function;\cr
 #' \strong{b} uses the Bellavia's cost function;\cr
+#' \strong{e} uses the Eastman's cost function;\cr
 #'
 #' \strong{-functions expressing cost as metabolic energy expenditure-}\cr
 #' \strong{p} uses the Pandolf et al.'s metabolic energy expenditure cost function;\cr
@@ -95,10 +98,12 @@
 #' \strong{hrz} uses the Herzog's metabolic energy expenditure cost function;\cr
 #' \strong{vl} uses the Van Leusen's metabolic energy expenditure cost function;\cr
 #' \strong{ls} uses the Llobera-Sluckin's metabolic energy expenditure cost function;\cr
-#' \strong{a} uses the Ardigo et al.'s metabolic energy expenditure cost function (for all the mentioned cost functions, see Details);\cr
+#' \strong{a} uses the Ardigo et al.'s metabolic energy expenditure cost function;\cr
+#' \strong{h} uses the Hare's metabolic energy expenditure cost function (for all the mentioned cost functions, see \code{\link{movecost}});\cr
 #' @param time time-unit expressed by the accumulated raster if Tobler's and other time-related cost functions are used;
 #' 'h' for hour, 'm' for minutes.
 #' @param move number of directions in which cells are connected: 4 (rook's case), 8 (queen's case), 16 (knight and one-cell queen moves; default).
+#' @param field value assigned to the cells coincidinng with the barrier (0 by default) (see \code{\link{movecost}}.
 #' @param cogn.slp  TRUE or FALSE (default) if the user wants or does not want the 'cognitive slope' to be used in place of the real slope (see \code{\link{movecost}}).
 #' @param sl.crit critical slope (in percent), typically in the range 8-16 (10 by default) (used by the wheeled-vehicle cost function; see \code{\link{movecost}}).
 #' @param W walker's body weight (in Kg; 70 by default; used by the Pandolf's and Van Leusen's cost function; see \code{\link{movecost}}).
@@ -156,7 +161,7 @@
 #' @seealso \code{\link{movecost}}
 #'
 #'
-movecorr <- function (dtm=NULL, a, b, lab.a="A", lab.b="B", cex.labs=0.8, studyplot=NULL, funct="t", time="h", move=16, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, rescale=FALSE, transp=0.5, export=FALSE){
+movecorr <- function (dtm=NULL, a, b, lab.a="A", lab.b="B", cex.labs=0.8, studyplot=NULL, barrier=NULL, funct="t", time="h", move=16, field=0, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, rescale=FALSE, transp=0.5, export=FALSE){
 
   #if no dtm is provided
   if (is.null(dtm)==TRUE) {
@@ -172,10 +177,10 @@ movecorr <- function (dtm=NULL, a, b, lab.a="A", lab.b="B", cex.labs=0.8, studyp
   if (length(a) < 2) {
 
   #calculate the accum cost surface and LCP around and from point a
-  res.a <- movecost::movecost(dtm=dtm, origin=a, destin=b, studyplot=studyplot, funct=funct, time=time, move=move, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, z=z, return.base=FALSE, graph.out=FALSE)
+  res.a <- movecost::movecost(dtm=dtm, origin=a, destin=b, studyplot=studyplot, barrier=barrier, funct=funct, time=time, move=move, field=field, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, z=z, return.base=FALSE, graph.out=FALSE)
 
   #calculate the accum cost surface and LCP around and from point b
-  res.b <- movecost::movecost(dtm=dtm, origin=b, destin=a, studyplot=studyplot, funct=funct, time=time, move=move, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, z=z, return.base=FALSE, graph.out=FALSE)
+  res.b <- movecost::movecost(dtm=dtm, origin=b, destin=a, studyplot=studyplot, barrier=barrier, funct=funct, time=time, move=move, field=field, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, z=z, return.base=FALSE, graph.out=FALSE)
 
   #combine the 2 accumulated cost surfaces obtained at the preceding steps
   res.corridor <- res.a$accumulated.cost.raster + res.b$accumulated.cost.raster
@@ -201,8 +206,8 @@ movecorr <- function (dtm=NULL, a, b, lab.a="A", lab.b="B", cex.labs=0.8, studyp
     #loop through all the locations to calculate the accumulated cost surfaces
     #and store them in the list
     for (i in 1:(ncol(pairw.list))) {
-      acc.cost.srf.a <- movecost::movecost(dtm=dtm, origin=a[pairw.list[,i][1],], studyplot=studyplot, funct=funct, time=time, move=move, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, return.base=FALSE, graph.out=FALSE)$accumulated.cost.raster
-      acc.cost.srf.b <- movecost::movecost(dtm=dtm, origin=a[pairw.list[,i][2],], studyplot=studyplot, funct=funct, time=time, move=move, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, return.base=FALSE, graph.out=FALSE)$accumulated.cost.raster
+      acc.cost.srf.a <- movecost::movecost(dtm=dtm, origin=a[pairw.list[,i][1],], studyplot=studyplot, barrier=barrier, funct=funct, time=time, move=move, field=field, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, return.base=FALSE, graph.out=FALSE)$accumulated.cost.raster
+      acc.cost.srf.b <- movecost::movecost(dtm=dtm, origin=a[pairw.list[,i][2],], studyplot=studyplot, barrier=barrier, funct=funct, time=time, move=move, field=field, cogn.slp=cogn.slp, sl.crit=sl.crit, W=W, L=L, N=N, V=V, return.base=FALSE, graph.out=FALSE)$accumulated.cost.raster
       corridors[[i]] <- acc.cost.srf.a + acc.cost.srf.b
       setTxtProgressBar(pb, i)
     }
@@ -410,6 +415,22 @@ movecorr <- function (dtm=NULL, a, b, lab.a="A", lab.b="B", cex.labs=0.8, studyp
     }
   }
 
+  if(funct=="h") {
+
+    #set the labels to be used within the returned plot
+    main.title <- "Least-cost corridor"
+    sub.title <- paste0("Cost based on the Hare's metabolic cost function \n cost in cal/km \n terrain factor N=", N)
+    legend.cost <- "metabolic cost cal/km"
+  }
+
+  if(funct=="e") {
+
+    #set the labels to be used within the returned plot
+    main.title <- "Least-cost corridor"
+    sub.title <- paste0("Cost based on the Eastman's cost function \n terrain factor N=", N)
+    legend.cost <- "cost"
+  }
+
   #plot the corridor raster
   raster::plot(res.corridor,
                main=main.title,
