@@ -3,7 +3,9 @@
 #' The function provides the facility to calculate the anisotropic accumulated cost of movement around a starting location and to optionally calculate least-cost path(s) toward
 #' one or multiple destinations. It implements different cost estimations related to human movement across the landscape.
 #' The function takes as input a Digital Terrain Model ('RasterLayer' class) and a point feature ('SpatialPointsDataFrame' class), the latter representing
-#' the starting location, i.e. the location from which the accumulated cost is calculated. \cr
+#' the starting location, i.e. the location from which the accumulated cost is calculated. Besides citing this package,
+#' you may want to refer to the following journal article: \strong{Alberti (2019) <doi:10.1016/j.softx.2019.100331>}.\cr
+#' Visit this \href{https://drive.google.com/file/d/1gLDrkZFh1b_glzCEqKdkPrer72JJ9Ffa/view?usp=sharing}{LINK} to access the package's vignette.\cr
 #'
 #' If the parameter 'destin' is fed with a dataset representing destination location(s) ('SpatialPointsDataFrame' class), the function also calculates
 #' least-cost path(s) plotted on the input DTM; the length of each path is saved under the variable 'length' stored in the 'LCPs' dataset ('SpatialLines' class) returned by the function.
@@ -28,7 +30,7 @@
 #' It is worth reminding the user(s) that all the input layers (i.e., DTM, start location, and destination locations) must use the same projected coordinate system.\cr
 #'
 #'
-#' Cost surface calculation:\cr
+#' \strong{Cost surface calculation}:\cr
 #' for the cost-surface and LCPs calculation, 'movecost' builds on functions from Jacob van Etten's
 #' \href{https://cran.r-project.org/package=gdistance}{gdistance} package.
 #' Under the hood, 'movecost' calculates the slope as rise over run, following the procedure described
@@ -37,7 +39,29 @@
 #' 16 (knight and one-cell queen moves) using the 'move' parameter (see 'Arguments').\cr
 #'
 #'
-#' Acquiring online elevation data:\cr
+#' \strong{Inibition of movement (barrier)}:\cr
+#' areas where the movement is inhibited can be fed into the analysis via the \code{barrier} parameter; SpatialLineDataFrame or SpatialPolygonDataFrame can be used.
+#' The barrier is assigned a conductance value of 0 (i.e., movement is inhibited) by default, but the user can assign any other value via the
+#' \code{field} parameter. Internally, the barrier creation rests on the \code{\link[leastcostpath]{create_barrier_cs}} function
+#' from the \emph{leastcostpath} package.\cr
+#'
+#' To test this facility, consider the following example:\cr
+#'
+#' First, we use in-built data to come up with a linear feature (i.e., a LCP) that we will later use as barrier:\cr
+#'
+#' result1 <- movecost(volc, destin.loc[1,], destin.loc[4,])\cr
+#'
+#' After, we calculate the LCP between two other locations, first not using any barrier (result2), then using the mentioned LCP (from result1)
+#' as a barrier (result3):\cr
+#'
+#' result2 <- movecost(volc, destin.loc[3,], destin.loc[6,], move=8)\cr
+#' result3 <- movecost(volc, destin.loc[3,], destin.loc[6,], barrier=result1$LCPs, move=8)\cr
+#'
+#' As apparent by comparing result2 to result3, when the barrier is used (result3), the LCP does not cross the barrier but is "forced"
+#' to make a long detour. \strong{Note} that the \code{move} parameter has been set to 8; if set to 16, the LCP will be "able" to jump the barrier.\cr
+#'
+#'
+#' \strong{Acquiring online elevation data}:\cr
 #' if a DTM is not provided, 'movecost()' will download elevation data from online sources.
 #' Elevation data will be aquired for the area enclosed  by the  polygon supplied by the 'studyplot' parameter (SpatialPolygonDataFrame class).
 #' To tap online elevation data, 'movecost' internally builds on the
@@ -66,7 +90,7 @@
 #' https://github.com/tilezen/joerd/blob/master/docs/data-sources.md#what-is-sourced-at-what-zooms. \cr
 #'
 #'
-#' Terrain slope and cognitive slope:\cr
+#' \strong{Terrain slope and cognitive slope}:\cr
 #' when it comes to the terrain slope, the function provides the facility to use the so-called 'cognitive slope',
 #' following Pingel TJ (2013), Modeling Slope as a Contributor to Route Selection in Mountainous Areas, in Cartography and Geographic Information Science, 37(2), 137-148.
 #' According to Pingel, "Humans tend to overestimate geographic slopes by a surprisingly high margin...This analysis indicates downhill slopes are overestimated
@@ -74,7 +98,7 @@
 #' if the parameter 'cogn.slp' is set to TRUE, positive slope values are preliminarily multiplied by 1.99, while negative slope values are multiplied by 2.31.
 #'
 #'
-#' Terrain factor (N):\cr
+#' \strong{Terrain factor (N)}:\cr
 #' virtually all the implemented cost functions (with few exceptions) can take into account a 'terrain factor' (N parameter; 1 by default), which
 #' represents the easiness/difficulty of moving on different terrain types. According to the type of terrain, the energy spent when walking
 #' increases. The same holds true for time, which increases because on a loose terrain (for instance) the walking speed decreases.
@@ -131,16 +155,14 @@
 #'   \item Loose sand = 2.10
 #' }
 #'
-#' Besides citing this package, you may want to refer to the following journal article:
-#' \strong{Alberti (2019) <doi:10.1016/j.softx.2019.100331>}.\cr
 #'
 #'
-#' Implemented cost functions:\cr
+#' \strong{Implemented cost functions}:\cr
 #' note that in what follows \strong{x[adj]} stands for slope as rise/run calculated for adjacent cells:\cr
 #'
 #' \strong{Tobler's hiking function (on-path) (speed in kmh)}:\cr
 #'
-#' \eqn{6 * exp(-3.5 * abs(x[adj] + 0.05))}\cr
+#' \eqn{ (6 * exp(-3.5 * abs(x[adj] + 0.05))) * (1/N) }\cr
 #'
 #'
 #' \strong{Tobler's hiking function (off-path) (speed in kmh)}:\cr
@@ -152,7 +174,7 @@
 #'
 #' \strong{Marquez-Perez et al.'s modified Tobler hiking function (speed in kmh)}:\cr
 #'
-#' \eqn{4.8 * exp(-5.3 * abs((x[adj] * 0.7) + 0.03))}\cr
+#' \eqn{ (4.8 * exp(-5.3 * abs((x[adj] * 0.7) + 0.03))) * (1/N) }\cr
 #'
 #' modified version of the Tobler's hiking function as proposed by Joaquin Marquez-Parez, Ismael Vallejo-Villalta & Jose I. Alvarez-Francoso (2017), "Estimated travel time for walking trails in natural areas",
 #' Geografisk Tidsskrift-Danish Journal of Geography, 117:1, 53-62, DOI: 10.1080/00167223.2017.1316212.\cr
@@ -160,7 +182,7 @@
 #'
 #' \strong{Irmischer-Clarke's modified Tobler hiking function (male, on-path; speed in kmh)}:\cr
 #'
-#' \eqn{(0.11 + exp(-(abs(x[adj])*100 + 5)^2 / (2 * 30)^2)) * 3.6}\cr
+#' \eqn{ ((0.11 + exp(-(abs(x[adj])*100 + 5)^2 / (2 * 30^2))) * 3.6) * (1/N) }\cr
 #'
 #' modified version of the Tobler's function as proposed for (male) on-path hiking by Irmischer, I. J., & Clarke, K. C. (2018). Measuring and modeling the speed of human navigation.
 #' Cartography and Geographic Information Science, 45(2), 177-186. https://doi.org/10.1080/15230406.2017.1292150.
@@ -176,7 +198,7 @@
 #'
 #' \strong{Irmischer-Clarke's modified Tobler hiking function (female, on-path; speed in kmh)}:\cr
 #'
-#' \eqn{(0.95 * (0.11 + exp(-(abs(x[adj]) * 100 + 5)^2/(2 * 30^2)))) * 3.6 }\cr
+#' \eqn{ ((0.95 * (0.11 + exp(-(abs(x[adj]) * 100 + 5)^2/(2 * 30^2)))) * 3.6) * (1/N) }\cr
 #'
 #' \strong{Irmischer-Clarke's modified Tobler hiking function (female, off-path; speed in kmh)}:\cr
 #'
@@ -185,7 +207,7 @@
 #'
 #'\strong{Uriarte Gonzalez's walking-time cost function}:\cr
 #'
-#' \eqn{1/ (0.0277 * (abs(x[adj])*100) + 0.6115)}\cr
+#' \eqn{ 1 / ((0.0277 * (abs(x[adj])*100) + 0.6115) * N) }\cr
 #'
 #' proposed by Uriarte Gonzalez;
 #' \strong{see}: Chapa Brunet, T., Garcia, J., Mayoral Herrera, V., & Uriarte Gonzalez, A. (2008). GIS landscape models for the study of preindustrial settlement patterns in Mediterranean areas.
@@ -198,7 +220,7 @@
 #'
 #' \strong{Marin Arroyo's walking-time cost function}:\cr
 #'
-#' \eqn{ ifelse((abs(x[adj])*100) < 0, 1 / (0.6 * ((abs(x[adj])*100)/23+1)), 1 / (0.6 * ((abs(x[adj])*100)/11+1)) }\cr
+#' \eqn{ ifelse((abs(x[adj])*100) < 0, 1 / ((0.6 * ((abs(x[adj])*100)/23+1))*N), 1 / ((0.6 * ((abs(x[adj])*100)/11+1))*N)) }\cr
 #'
 #' used by Marin Arroyo A.B. (2009), The use of optimal foraging theory to estimate Late Glacial site catchments areas from a central place:
 #' the case of eastern Cantabria, Span, in Journal of Anthropological Archaeology 28, 27-36.
@@ -226,7 +248,7 @@
 #'
 #' \strong{Garmy, Kaddouri, Rozenblat, and Schneider's hiking function (speed in kmh)}:\cr
 #'
-#' \eqn{4 * exp(-0.008 * ((atan(abs(x[adj]))*180/pi)^2))}\cr
+#' \eqn{ (4 * exp(-0.008 * ((atan(abs(x[adj]))*180/pi)^2))) * (1/N) }\cr
 #'
 #' slope in degrees;
 #' \strong{see}: Herzog, I. (2020). Spatial Analysis Based on Cost Functions. In Gillings M, Haciguzeller P, Lock G (eds), "Archaeological Spatial Analysis. A Methodological Guide.",
@@ -236,7 +258,7 @@
 #'
 #' \strong{Rees' hiking function (speed in kmh)}:\cr
 #'
-#' \eqn{(1 / (0.75 + 0.09 * abs(x[adj]) + 14.6 * (abs(x[adj]))^2)) * 3.6}\cr
+#' \eqn{ ((1 / (0.75 + 0.09 * abs(x[adj]) + 14.6 * (abs(x[adj]))^2)) * 3.6) * (1/N) }\cr
 #'
 #' Rees' slope-dependant cost function; it is originally expressed in terms of time (1/v in Rees' publication);
 #' here it is the reciprocal of time (i.e. speed) that is used in order to eventually get the reciprocal of speed (i.e. time).
@@ -250,7 +272,7 @@
 #'
 #'\strong{Kondo-Seino's modified Tobler hiking function (speed in kmh)}:\cr
 #'
-#' \eqn{ ifelse(abs(x[adj]) >= -0.07, 5.1 * exp(-2.25 * abs(x[adj] + 0.07)), 5.1 * exp(-1.5 * abs(x[adj] + 0.07))) }\cr
+#' \eqn{ ifelse(abs(x[adj]) >= -0.07, (5.1 * exp(-2.25 * abs(x[adj] + 0.07))) * (1/N), (5.1 * exp(-1.5 * abs(x[adj] + 0.07)))) * (1/N) }\cr
 #'
 #' Kondo-Seino's modified Tobler hiking function; it expresses walking speed in Kmh; slope as rise/run;
 #' \strong{see} Kondo Y., Seino Y. (2010). GPS-aided Walking Experiments and Data-driven Travel Cost Modelingon the Historical Road of Nakasendo-Kisoji
@@ -262,7 +284,7 @@
 #'
 #' \strong{Wheeled-vehicle critical slope cost function}:\cr
 #'
-#' \eqn{1 / (1 + ((abs(x[adj])*100) / sl.crit)^2)}\cr
+#' \eqn{ 1 / ((1 + ((abs(x[adj])*100) / sl.crit)^2) * N) }\cr
 #'
 #' where \eqn{sl.crit} (=critical slope, in percent) is "the transition where switchbacks become more effective than direct uphill or downhill paths" and typically is in the range 8-16;
 #' \strong{see} Herzog, I. (2016). Potential and Limits of Optimal Path Analysis. In A. Bevan & M. Lake (Eds.), Computational Approaches to Archaeological Spaces (pp. 179-211). New York: Routledge. \cr
@@ -271,7 +293,7 @@
 #'
 #'\strong{Relative energetic expenditure cost function}:\cr
 #'
-#' \eqn{1 / (tan((atan(abs(x[adj]))*180/pi)*pi/180) / tan (1*pi/180))}\cr
+#' \eqn{ 1 / ((tan((atan(abs(x[adj]))*180/pi)*pi/180) / tan (1*pi/180)) * N) }\cr
 #'
 #' slope-based cost function expressing change in potential energy expenditure;
 #' \strong{see} Conolly, J., & Lake, M. (2006). Geographic Information Systems in Archaeology. Cambridge: Cambridge University Press, p. 220;
@@ -291,9 +313,19 @@
 #'
 #'
 #'
+#' \strong{Eastman's cost function}:\cr
+#'
+#' \eqn{ 1 / ((0.031*(atan(abs(x[adj]))*180/pi)^2-0.025*(atan(abs(x[adj]))*180/pi)+1)*N) }\cr
+#'
+#' proposed by J.R. Eastman, it measures abstract cost; slope in degrees.
+#' \strong{See}: Vaissie E., Mobility of Paleolithic Populations: Biomechanical Considerations and Spatiotemporal Modelling,
+#' in PaleoAnthropology 2021 (1): 120-144 (with previous reference to Eastman 1999).\cr
+#'
+#'
+#'
 #' \strong{Pandolf et al.'s metabolic energy expenditure cost function (in Watts)}:\cr
 #'
-#' \eqn{1 / (1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * V^2 + 0.35 * V * (abs(x[adj])*100)))}\cr
+#' \eqn{ 1 / ((1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * (V^2) + 0.35 * V * (abs(x[adj])*100)))*N) }\cr
 #'
 #' where \eqn{W} is the walker's body weight (Kg), \eqn{L} is the carried load (in Kg), \eqn{V} is the velocity in m/s, \eqn{N} is a coefficient representing ease of movement on the terrain (see above).
 #' \strong{Note} that if \eqn{V} is set to 0 by the user, it is internally worked out on the basis of the Tobler function for on-path hiking; therefore, \eqn{V} will not be
@@ -332,7 +364,7 @@
 #'
 #' \strong{Minetti et al.'s metabolic energy cost function (in J/(kg*m))}:\cr
 #'
-#' \eqn{ 1 / ((280.5 * abs(x[adj])^5) - (58.7 * abs(x[adj])^4) - (76.8 * abs(x[adj])^3) + (51.9 * abs(x[adj])^2) + (19.6 * abs(x[adj])) + 2.5) }\cr
+#' \eqn{ 1 / (((280.5 * abs(x[adj])^5) - (58.7 * abs(x[adj])^4) - (76.8 * abs(x[adj])^3) + (51.9 * abs(x[adj])^2) + (19.6 * abs(x[adj])) + 2.5) * N) }\cr
 #'
 #' \strong{see} Minetti A.E., Moia C., Roi G.S., Susta D., Ferretti G. (2002), Enery cost of walking and running at extreme uphilland downhill slopes,
 #' in Journal of Applied Physiology 93, 1039-1046. \strong{Note} that this equation is valid for slopes in the range -0.5/0.5; outside this range,
@@ -345,7 +377,7 @@
 #'
 #' \strong{Herzog's metabolic cost function in J/(kg*m)}:\cr
 #'
-#' \eqn{1 / ((1337.8 * abs(x[adj])^6) + (278.19 * abs(x[adj])^5) - (517.39 * abs(x[adj])^4) - (78.199 * abs(x[adj])^3) + (93.419 * abs(x[adj])^2) + (19.825 * abs(x[adj])) + 1.64)}\cr
+#' \eqn{1 / (((1337.8 * abs(x[adj])^6) + (278.19 * abs(x[adj])^5) - (517.39 * abs(x[adj])^4) - (78.199 * abs(x[adj])^3) + (93.419 * abs(x[adj])^2) + (19.825 * abs(x[adj])) + 1.64) * N)  }\cr
 #'
 #' \strong{see} Herzog, I. (2016). Potential and Limits of Optimal Path Analysis. In A. Bevan & M. Lake (Eds.), Computational Approaches to Archaeological Spaces (pp. 179-211). New York: Routledge.
 #' Herzog suggests to use this as a 6th degree polynomial approximation of the Minetti et al's cost function (see above).\cr
@@ -354,7 +386,7 @@
 #'
 #' \strong{Van Leusen's metabolic energy expenditure cost function (in Watts)}:\cr
 #'
-#' \eqn{1 / (1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * V^2 + 0.35 * V * abs(x[adj])*100) + 10))}\cr
+#' \eqn{ 1 / ((1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * (V^2) + 0.35 * V * ((abs(x[adj])*100) + 10)))*N) }\cr
 #'
 #' which modifies the Pandolf et al.'s equation; \strong{see} Van Leusen, P. M. (2002). Pattern to process: methodological investigations into the formation and interpretation of spatial patterns in archaeological landscapes. University of Groningen.
 #' \strong{Note} that, as per Herzog, I. (2013). Least-cost Paths - Some Methodological Issues, Internet Archaeology 36 (http://intarch.ac.uk/journal/issue36/index.html) and
@@ -369,7 +401,7 @@
 #'
 #' \strong{Llobera-Sluckin's metabolic energy expenditure cost function (in KJ/m)}:\cr
 #'
-#' \eqn{1 / (2.635 + (17.37 * abs(x[adj])) + (42.37 * abs(x[adj])^2) - (21.43 * abs(x[adj])^3) + (14.93 * abs(x[adj])^4))}\cr
+#' \eqn{ 1 / ((2.635 + (17.37 * abs(x[adj])) + (42.37 * abs(x[adj])^2) - (21.43 * abs(x[adj])^3) + (14.93 * abs(x[adj])^4)) * N)  }\cr
 #'
 #' for which \strong{see} Llobera M.-Sluckin T.J. (2007). Zigzagging: Theoretical insights on climbing strategies, Journal of Theoretical Biology 249, 206-217.\cr
 #'
@@ -377,7 +409,7 @@
 #'
 #' \strong{Ardigo et al.'s metabolic energy expenditure cost function (in J/(kg*m))}:\cr
 #'
-#' \eqn{ 1 / (1.866 * exp(4.911*abs(x[adj])) * V^2 - 3.773 * exp(3.416*abs(x[adj])) * V + (45.71*abs(x[adj]^2) + 18.90*abs(x[adj])) + 4.456) }\cr
+#' \eqn{ 1 / ((1.866 * exp(4.911*abs(x[adj])) * V^2 - 3.773 * exp(3.416*abs(x[adj])) * V + (45.71*abs(x[adj]^2) + 18.90*abs(x[adj])) + 4.456) * N) }\cr
 #'
 #' \strong{see} Ardigo L.P., Saibene F., Minetti A.E. (2003), The optimal locomotion on gradients: walking, running or cycling?, in
 #' Eur J Appl Physiol 90, 365-371. If \eqn{V} is set to 0 by the user, it is internally worked out on the basis of the Tobler function for on-path hiking; therefore,
@@ -385,6 +417,17 @@
 #'
 #'
 #'
+#' \strong{Hare's metabolic energy expenditure cost function (in cal/km)}:\cr
+#'
+#' \eqn{ 1 / ((48+30/(1/(6 * exp(-3.5 * abs(x[adj] + 0.05)))))*N) }\cr
+#'
+#' \strong{see} Hare T.S., Using Measures of Cost Distance in the Estimation of Polity Bounrdaries in the Post Classic
+#' Yautepec valley, Mexico, in Journal of Archaeological Science 31 (2004). Energetic expenditure is expressed in calories per km; walking speed
+#' is internally worked out from the DTM using the on-path Tobler's hiking function, which is expressed as its reciprocal; walking speed in km/h as per original Tobler's equation
+#' and as requested by Hare's function.\cr
+#'
+#'
+#'
 #' \strong{Note} that the walking-speed-related cost functions listed above are used as they are, while the other functions are reciprocated.
 #' This is done since "gdistance works with conductivity rather than the more usual approach using costs"; therefore
 #' "we need inverse cost functions" (Nakoinz-Knitter (2016). "Modelling Human Behaviour in Landscapes". New York: Springer, p. 183).
@@ -397,6 +440,7 @@
 #' @param origin location from which the cost surface is calculated (SpatialPointsDataFrame class).
 #' @param destin location(s) to which least-cost path(s) is calculated (SpatialPointsDataFrame class).
 #' @param studyplot polygon (SpatialPolygonDataFrame class) representing the study area for which online elevation data are aquired (see Details); NULL is default.
+#' @param barrier area where the movement is inhibited (SpatialLineDataFrame or SpatialPolygonDataFrame class).
 #' @param funct cost function to be used:\cr
 #'
 #' \strong{-functions expressing cost as walking time-}\cr
@@ -420,6 +464,7 @@
 #' \strong{-functions expressing abstract cost-}\cr
 #' \strong{ree} uses the relative energetic expenditure cost function;\cr
 #' \strong{b} uses the Bellavia's cost function;\cr
+#' \strong{e} uses the Eastman's cost function;\cr
 #'
 #' \strong{-functions expressing cost as metabolic energy expenditure-}\cr
 #' \strong{p} uses the Pandolf et al.'s metabolic energy expenditure cost function;\cr
@@ -428,17 +473,19 @@
 #' \strong{hrz} uses the Herzog's metabolic energy expenditure cost function;\cr
 #' \strong{vl} uses the Van Leusen's metabolic energy expenditure cost function;\cr
 #' \strong{ls} uses the Llobera-Sluckin's metabolic energy expenditure cost function;\cr
-#' \strong{a} uses the Ardigo et al.'s metabolic energy expenditure cost function (for all the mentioned cost functions, see Details);\cr
+#' \strong{a} uses the Ardigo et al.'s metabolic energy expenditure cost function;\cr
+#' \strong{h} uses the Hare's metabolic energy expenditure cost function (for all the mentioned cost functions, see Details);\cr
 #' @param time time-unit expressed by the accumulated raster and by the isolines if Tobler's and other time-related cost functions are used;
 #' 'h' for hour, 'm' for minutes.
 #' @param outp type of output: 'raster' or 'contours' (see Details).
 #' @param move number of directions in which cells are connected: 4 (rook's case), 8 (queen's case), 16 (knight and one-cell queen moves; default).
+#' @param field value assigned to the cells coincidinng with the barrier (0 by default).
 #' @param cogn.slp  TRUE or FALSE (default) if the user wants or does not want the 'cognitive slope' to be used in place of the real slope (see Details).
 #' @param sl.crit critical slope (in percent), typically in the range 8-16 (10 by default) (used by the wheeled-vehicle cost function; see Details).
 #' @param W walker's body weight (in Kg; 70 by default; used by the Pandolf's and Van Leusen's cost function; see Details).
 #' @param L carried load weight (in Kg; 0 by default; used by the Pandolf's and Van Leusen's cost function; see Details).
 #' @param N coefficient representing ease of movement (1 by default) (see Details).
-#' @param V speed in m/s (1.2 by default) (used by the Pandolf et al.'s, Pandolf et al.s with correction factor, Van Leusen's, and Ardigo et al.'s cost function; if set to 0, it is internally worked out on the basis of Tobler on-path hiking function; see Details.
+#' @param V speed in m/s (1.2 by default) (used by the Pandolf et al.'s, Pandolf et al.s with correction factor, Van Leusen's, and Ardigo et al.'s cost function; if set to 0, it is internally worked out on the basis of Tobler on-path hiking function; see Details).
 #' @param z zoom level for the elevation data downloaded from online sources (0 to 15; 9 by default) (see Details and \code{\link[elevatr]{get_elev_raster}}).
 #' @param return.base TRUE or FALSE (default) if the user wants or does not want the least-cost paths back to the origin to be calculated and plotted (as dashed lines).
 #' @param rb.lty line type used to represent the least-cost paths back to the origin in the returned plot (2 by default; dashed line; see 'lty' parameter in \code{\link[graphics]{par}}).
@@ -467,6 +514,7 @@
 ##'  \item{dest.loc.w.cost: }{copy of the input destination location(s) dataset with a new variable ('cost') added; if
 ##'  the cost is expressed in terms of time, the 'cost' variable will store the time values in decimal numbers, while another variable named
 ##'  'cost_hms' will store the time values in sexagesimmal numbers (hours, minutes, seconds)}
+##'  \item{conductance: }{conductance 'Transitional Layer', returned because internally used by the 'movenetw()' function}
 ##' }
 ##'
 ##'
@@ -477,6 +525,7 @@
 #' @importFrom chron times
 #' @importFrom grDevices terrain.colors topo.colors grey
 #' @importFrom graphics layout par
+#' @importFrom leastcostpath create_barrier_cs
 #'
 #'
 #' @examples
@@ -519,7 +568,7 @@
 #' @seealso \code{\link[elevatr]{get_elev_raster}}, \code{\link{movecorr}}, \code{\link{movebound}}, \code{\link{movealloc}},  \code{\link{movecomp}}, \code{\link{movenetw}}
 #'
 #'
-movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t", time="h", outp="r", move=16, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, return.base=FALSE, rb.lty=2, breaks=NULL, cont.lab=TRUE, destin.lab=TRUE, cex.breaks=0.6, cex.lcp.lab=0.6, graph.out=TRUE, transp=0.5, oneplot=TRUE, export=FALSE){
+movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NULL, funct="t", time="h", outp="r", move=16, field=0, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, return.base=FALSE, rb.lty=2, breaks=NULL, cont.lab=TRUE, destin.lab=TRUE, cex.breaks=0.6, cex.lcp.lab=0.6, graph.out=TRUE, transp=0.5, oneplot=TRUE, export=FALSE){
 
   #deactivate the warning messages because a warning that can be safely ignored will be produced by the procedure
   #used to get slope as rise over run
@@ -575,7 +624,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
 
   if(funct=="mp") {
     #Marquez-Perez et al.'s modified Tobler hiking function; kmh
-    cost_function <- function(x){ (4.8 * exp(-5.3 * abs((x[adj] * 0.7) + 0.03))) * (1/N)}
+    cost_function <- function(x){ (4.8 * exp(-5.3 * abs((x[adj] * 0.7) + 0.03))) * (1/N) }
 
     #set the labels to be used within the returned plot
     main.title <- paste0("Walking-time isochrones (in ", time, ") around origin")
@@ -599,7 +648,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
     #Irmischer-Clarke's modified Tobler hiking function; originally in m/s (male, on-path);
     # the formula is reshaped (multiplied by 3.6) below to turn it into kmh for consistency with the other Tobler-related cost functions;
     # Slope in percent.
-    cost_function <- function(x){ ((0.11 + exp(-(abs(x[adj])*100 + 5)^2 / (2 * 30^2))) * 3.6) * (1/N)}
+    cost_function <- function(x){ ((0.11 + exp(-(abs(x[adj])*100 + 5)^2 / (2 * 30^2))) * 3.6) * (1/N) }
 
     #set the labels to be used within the returned plot
     main.title <- paste0("Walking-time isochrones (in ", time, ") around origin")
@@ -740,12 +789,12 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
   if(funct=="vl") {
     #Van Leusen's metabolic energy expenditure cost function
     #note: V is velocity in m/s; the slope is in percent
-    #if V is set to 0 by the user, it is worked out from the DTM using the off-path Tobler hiking function
+    #if V is set to 0 by the user, it is worked out from the DTM using the on-path Tobler hiking function
     #which is expressed as its reciprocal and is multiplied by 0.278 to turn kmh to m/s
     if (V==0) {
-      cost_function <- function(x){ 1 / (1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * ((1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278))^2) + 0.35 * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278)) * ((abs(x[adj])*100) + 10))) }
+      cost_function <- function(x){ 1 / ((1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * ((1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278))^2) + 0.35 * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278)) * ((abs(x[adj])*100) + 10)))*N) }
     } else {
-      cost_function <- function(x){ 1 / (1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * (V^2) + 0.35 * V * ((abs(x[adj])*100) + 10))) }
+      cost_function <- function(x){ 1 / ((1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * (V^2) + 0.35 * V * ((abs(x[adj])*100) + 10)))*N) }
     }
 
     #set the labels to be used within the returned plot
@@ -763,12 +812,12 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
   if(funct=="p") {
     #Pandolf et al.'s metabolic energy expenditure cost function
     #note: V is velocity in m/s; the slope is expressed in percent
-    #if V is set to 0 by the user, it is worked out from the DTM using the off-path Tobler hiking function
+    #if V is set to 0 by the user, it is worked out from the DTM using the on-path Tobler hiking function
     #which is expressed as its reciprocal and is multiplied by 0.278 to turn kmh to m/s
     if (V==0) {
-      cost_function <- function(x){ 1 / (1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * ((1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278))^2) + 0.35 * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278)) * (abs(x[adj])*100))) }
+      cost_function <- function(x){ 1 / ((1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * ((1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278))^2) + 0.35 * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278)) * (abs(x[adj])*100)))*N) }
     } else {
-      cost_function <- function(x){ 1 / (1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * (V^2) + 0.35 * V * (abs(x[adj])*100))) }
+      cost_function <- function(x){ 1 / ((1.5 * W + 2.0 * (W + L) * (L / W)^2 + N * (W + L) * (1.5 * (V^2) + 0.35 * V * (abs(x[adj])*100)))*N) }
     }
 
     #set the labels to be used within the returned plot
@@ -786,7 +835,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
   if(funct=="pcf") {
     #Pandolf et al.'s metabolic energy expenditure cost function with CORRECTION FACTOR
     #note: V is velocity in m/s; the slope is expressed in percent
-    #if V is set to 0 by the user, it is worked out from the DTM using the off-path Tobler hiking function
+    #if V is set to 0 by the user, it is worked out from the DTM using the on-path Tobler hiking function
     #which is expressed as its reciprocal and is multiplied by 0.278 to turn kmh to m/s
     if (V==0) {
       cost_function <- function(x){ ifelse(abs(x[adj])*100 > 0 , 1 / (1.5 * W + 2.0 * (W+L) * (L/W)^2 + N * (W+L) * (1.5 * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278))^2 + 0.35 * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278)) * (abs(x[adj])*100))),
@@ -861,7 +910,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
   if(funct=="a") {
     #Ardigo et al's energy cost function; slope as rise/run (gradient)
     #cost in J/(kg*m)
-    #if V is set to 0 by the user, it is worked out from the DTM using the off-path Tobler hiking function
+    #if V is set to 0 by the user, it is worked out from the DTM using the on-path Tobler hiking function
     #which is expressed as its reciprocal and is multiplied by 0.278 to turn kmh to m/s
     if (V==0) {
       cost_function <- function(x){ 1 / ((1.866 * exp(4.911*abs(x[adj])) * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278))^2 - 3.773 * exp(3.416*abs(x[adj])) * (1 / ((6 * exp(-3.5 * abs(x[adj] + 0.05))) * 0.278)) + (45.71*abs(x[adj]^2) + 18.90*abs(x[adj])) + 4.456) * N) }
@@ -881,6 +930,31 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
     }
   }
 
+  if(funct=="h") {
+    #energetic expenditure in calories per km, following Hare 2004;
+    #walking speed is worked out from the DTM using the on-path Tobler hiking function,
+    #which is expressed as its reciprocal; speed in km/h as per original Tobler's function and as requested by Hare's function
+    cost_function <- function(x){ 1 / ((48+30/(1/(6 * exp(-3.5 * abs(x[adj] + 0.05)))))*N) }
+
+    #set the labels to be used within the returned plot
+    main.title <- "Accumulated cost isolines around origin"
+    sub.title <- paste0("Cost based on the Hare's metabolic cost function \n cost in cal/km \n terrain factor N=", N)
+    legend.cost <- "metabolic cost cal/km"
+    sub.title.lcp.plot <- paste0("LCP(s) and cost distance(s) based on the Hare's metabolic cost function \ncost in cal/km; terrain factor N=", N, "\nblack dot=start location\n red dot(s)=destination location(s)")
+  }
+
+  if(funct=="e") {
+    #Eastman's cost function; it measures abstract cost;
+    #slope is originally in degrees; (atan(abs(x[adj]))*180/pi) turns rise/run into degrees
+    cost_function <- function(x){ 1 / ((0.031 * (atan(abs(x[adj]))*180/pi)^2 - 0.025 * (atan(abs(x[adj]))*180/pi) + 1)*N) }
+
+    #set the labels to be used within the returned plot
+    main.title <- "Accumulated cost isolines around origin"
+    sub.title <- paste0("Cost based on the Eastman's cost function \n terrain factor N=", N)
+    legend.cost <- "cost"
+    sub.title.lcp.plot <- paste0("LCP(s) and cost distance(s) based on the Eastman's cost function \n terrain factor N=", N, "\nblack dot=start location\n red dot(s)=destination location(s)")
+  }
+
   #cost calculation for walking-speed-based cost functions
   if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks") {
 
@@ -898,6 +972,14 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
     #correct the speed values taking into account the distance between cell centers
     Conductance <- gdistance::geoCorrection(speed)
 
+    #if the 'barrier' parameter in not NULL...
+    if (is.null(barrier)==FALSE) {
+      #...create a barrier transitional layers via the 'create_barrier_cs' function
+      barrier.TL <- leastcostpath::create_barrier_cs(dtm, barrier, neighbours=move, field=field)
+      #use map algebra to "incorporate" the barrier to the conductance layer
+      Conductance <- Conductance*barrier.TL
+    }
+
     #cost-surface raster to be exported (the division turns ms back to kmh)
     cost.surface.to.export <- raster::raster(speed) / 0.278
   }
@@ -905,7 +987,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
   #cost calculation for OTHER TYPES of cost functions;
   #note the Uriarte Gonzalez's and Marin Arroyo's slope-dependant walking-time cost function are in this group since (unlike the above functions)
   #they expresses cost as time NOT speed
-  if (funct=="ree" | funct=="hrz" | funct=="wcs" | funct=="vl" | funct=="p" | funct=="ug" | funct=="ls" | funct=="b" | funct=="m" | funct=="ma" | funct=="a" | funct=="pcf") {
+  if (funct=="ree" | funct=="hrz" | funct=="wcs" | funct=="vl" | funct=="p" | funct=="ug" | funct=="ls" | funct=="b" | funct=="m" | funct=="ma" | funct=="a" | funct=="pcf" | funct=="h" | funct=="e") {
 
     #restrict the cost calculation to adjacent cells by creating an index for adjacent cells (adj) with the function 'adjacent'
     adj <- raster::adjacent(dtm, cells=1:raster::ncell(dtm), pairs=TRUE, directions=move)
@@ -918,6 +1000,14 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
     #correct the cost values taking into account the distance between cell centers
     Conductance <- gdistance::geoCorrection(cost)
 
+    #if the 'barrier' parameter in not NULL...
+    if (is.null(barrier)==FALSE) {
+      #...create a barrier transitional layers via the 'create_barrier_cs' function
+      barrier.TL <- leastcostpath::create_barrier_cs(dtm, barrier, neighbours=move, field=field)
+      #use map algebra to "incorporate" the barrier to the conductance layer
+      Conductance <- Conductance*barrier.TL
+    }
+
     #cost-surface raster to be exported
     cost.surface.to.export <- raster::raster(cost)
   }
@@ -1173,5 +1263,6 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, funct="t",
                   "isolines" = isolines,
                   "LCPs"=sPath,
                   "LCPs.back"=sPath.back,
-                  "dest.loc.w.cost"=destin)
+                  "dest.loc.w.cost"=destin,
+                  "conductance"=Conductance)
 }
