@@ -1,7 +1,11 @@
 #' R function for calculating least-cost path network
 #'
-#' The function provides the facility to calculate LCPs between multiple origins. The result is a network of LCPs connecting
-#' each origin location to all the others locations. Optionally, a raster representing the density of the LCPs network can be produced.
+#' The function provides the facility to calculate LCPs between multiple origins.
+#' Two types of networks are produced: one where each origin location is connected to all the others locations; one where
+#' only pairs of neighboring locations are connected. In other words, in the latter case, each location is connected to the location that is the
+#' nearest in terms of walking cost, either in terms of time or energy (or abstract cost), according to the selected cost function.
+#' Optionally, a raster representing the density of the first type of network can be produced.\cr
+#' Visit this \href{https://drive.google.com/file/d/1gLDrkZFh1b_glzCEqKdkPrer72JJ9Ffa/view?usp=sharing}{LINK} to access the package's vignette.\cr
 #'
 #' Like 'movecost()', the function just requires an input DTM ('RasterLayer' class) and an origin dataset  ('SpatialPointsDataFrame' class).
 #' If a DTM is not provided, 'movenetw()' downloads elevation data from online sources for the area enclosed by the polygon fed via
@@ -10,21 +14,25 @@
 #'
 #' 'movenetw()' produces a plot representing the input DTM overlaid by an hillshade raster, whose transparency can be adjusted using
 #' the 'transp' parameter. On the rendered plot, the LPCs network ('SpatialLinesDataFrame' class) is represented by black lines. Optionally,
-#' by setting the parameter 'lcp.dens' to TRUE, the function produces a raster representing the density of LCPs. The raster, rendered
-#' overlaid to an hillshade visualization, expresses the density of LCPs as percentages. The percentages are calculated in relation to the
-#' maximum number of LCPs passing through the same cell stored in the raster. A density raster expressing counts is NOT rendered BUT is returned by the function.
-#' The density raster retains the cell size and coordinate system of the input DTM.\cr
+#' by setting the parameter 'lcp.dens' to TRUE, the function produces a raster representing the density of the LCPs connecting each location to all the
+#' other locations. The raster, which is rendered overlaid to an hillshade visualization, expresses the density of LCPs as percentages.
+#' The percentages are calculated in relation to the maximum number of LCPs passing through the same cell stored in the raster.
+#' A density raster expressing counts is NOT rendered BUT is returned by the function. The density raster retains the cell size and coordinate system of the input DTM.\cr
 #'
 #' The function returns a list storing the DTM (only in case this has not been fed into the function but aquired online), a list of LCPs
-#' split by origin, a SpatialLineDataFrame representing the merged LCPs, and two rasters representing the LCPs network density
-#' expressed as counts and percentages respectively.
+#' split by origin, a SpatialLineDataFrame representing the merged LCPs, two rasters representing the LCPs network density
+#' expressed as counts and percentages respectively, and cost matrices. As for the latter, if the selected cost function defines cost as
+#' walking time, two matrices are returned, one expressing time in minutes, one in hours (\strong{note} that the values are in decimal format).
+#' If the selected cost function expresses cost differently (i.e., energy or abstract cost), the two above mentioned cost matrices will be set to NULL,
+#' and a third cost matrix will store all the pair-wise costs.\cr
 #'
-#' The mentioned data can be exported by setting the 'export' parameter to TRUE. The LCPs network (exported as a shapefile)
+#' The above mentioned data (DTM, LCPs, network density) can be exported by setting the 'export' parameter to TRUE. The LCPs network (exported as a shapefile)
 #' and the density raster (as a GeoTiff) will bear a suffix indicating the used cost function.\cr
 #'
 #' @param dtm Digital Terrain Model (RasterLayer class); if not provided, elevation data will be acquired online for the area enclosed by the 'studyplot' parameter (see \code{\link{movecost}}).
 #' @param origin location(s) around which the boundary(ies) is calculated (SpatialPointsDataFrame class).
 #' @param studyplot polygon (SpatialPolygonDataFrame class) representing the study area for which online elevation data are aquired (see \code{\link{movecost}}); NULL is default.
+#' @param barrier area where the movement is inhibited (SpatialLineDataFrame or SpatialPolygonDataFrame class) (see \code{\link{movecost}}.
 #' @param funct cost function to be used (for details on each of the following, see \code{\link{movecost}}):\cr
 #' \strong{-functions expressing cost as walking time-}\cr
 #' \strong{t} (default) uses the on-path Tobler's hiking function;\cr
@@ -47,6 +55,7 @@
 #' \strong{-functions expressing abstract cost-}\cr
 #' \strong{ree} uses the relative energetic expenditure cost function;\cr
 #' \strong{b} uses the Bellavia's cost function;\cr
+#' \strong{e} uses the Eastman's cost function;\cr
 #'
 #' \strong{-functions expressing cost as metabolic energy expenditure-}\cr
 #' \strong{p} uses the Pandolf et al.'s metabolic energy expenditure cost function;\cr
@@ -55,8 +64,10 @@
 #' \strong{hrz} uses the Herzog's metabolic energy expenditure cost function;\cr
 #' \strong{vl} uses the Van Leusen's metabolic energy expenditure cost function;\cr
 #' \strong{ls} uses the Llobera-Sluckin's metabolic energy expenditure cost function;\cr
-#' \strong{a} uses the Ardigo et al.'s metabolic energy expenditure cost function (for all the mentioned cost functions, see Details);\cr
+#' \strong{a} uses the Ardigo et al.'s metabolic energy expenditure cost function;\cr
+#' \strong{h} uses the Hare's metabolic energy expenditure cost function (for all the mentioned cost functions, see \code{\link{movecost}});\cr
 #' @param move number of directions in which cells are connected: 4 (rook's case), 8 (queen's case), 16 (knight and one-cell queen moves; default).
+#' @param field value assigned to the cells coincidinng with the barrier (0 by default) (see \code{\link{movecost}}.
 #' @param cogn.slp  TRUE or FALSE (default) if the user wants or does not want the 'cognitive slope' to be used in place of the real slope (see \code{\link{movecost}}).
 #' @param sl.crit critical slope (in percent), typically in the range 8-16 (10 by default) (used by the wheeled-vehicle cost function; see \code{\link{movecost}}).
 #' @param W walker's body weight (in Kg; 70 by default; used by the Pandolf's and Van Leusen's cost function; see \code{\link{movecost}}).
@@ -66,7 +77,6 @@
 #' @param z zoom level for the elevation data downloaded from online sources (from 0 to 15; 9 by default) (see \code{\link{movecost}} and \code{\link[elevatr]{get_elev_raster}}).
 #' @param lcp.dens TRUE or FALSE (default) if the user wants or does not want the least-cost paths density raster to be produced.
 #' @param transp set the transparency of the hillshade raster that is plotted over the DTM (0.5 by default).
-#' @param oneplot TRUE (default) or FALSE if the user wants or does not want the plots displayed in a single window.
 #' @param export TRUE or FALSE (default) if the user wants or does not want the LCPs network to be exported as a shapefile, and the LCPs network density as a GeoTiff; the DTM is exported only if it was not provided by the user
 #' and downloaded by the function from online sources.
 #'
@@ -74,8 +84,14 @@
 ##'  \item{dtm: }{Digital Terrain Model ('RasterLayer' class); returned only if aquired online}
 ##'  \item{LCPs.netw: }{list containing the LCPs ('SpatialLinesDataFrame' class) split by origin}
 ##'  \item{LCPs.netw.merged: }{'SpatialLinesDataFrame' corresponding to the merged LCPs}
+##'  \item{LCPs.netw.neigh: }{list containing the LCPs between neighboring locations ('SpatialLinesDataFrame' class) split by origin}
+##'  \item{LCPs.netw.merged: }{'SpatialLinesDataFrame' corresponding to the merged LCPs between neighboring locations}
 ##'  \item{LCPs.density.count: }{raster ('RasterLayer' class) representing the counts of LCPs on each raster's cell}
-##'  \item{LCPs.density.perc: }{same as the preceding, but re-expressing the counts as percentages)}
+##'  \item{LCPs.density.perc: }{same as the preceding, but re-expressing the counts as percentages}
+##'  \item{cost.matrix.min: }{matrix of cost between locations, expressing cost in minutes}
+##'  \item{cost.matrix.hr: }{matrix of cost between locations, expressing cost in hours}
+##'  \item{cost.matrix: }{matrix of cost between locations, expressing cost either in energy or abstract cost, depending on the
+##'  used cost function}
 ##' }
 ##'
 #' @keywords movenetw
@@ -83,6 +99,7 @@
 #' @importFrom raster raster hillShade terrain rasterize cellStats extend crs
 #' @importFrom spatstat.geom pixellate
 #' @import maptools
+#' @importFrom sp SpatialLinesDataFrame
 #' @importFrom elevatr get_elev_raster
 #' @importFrom grDevices terrain.colors topo.colors grey
 #' @importFrom methods as
@@ -105,7 +122,7 @@
 #' @seealso \code{\link{movecost}}
 #'
 #'
-movenetw <- function (dtm=NULL, origin, studyplot=NULL, funct="t", move=16, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, lcp.dens=FALSE, transp=0.5, oneplot=TRUE, export=FALSE){
+movenetw <- function (dtm=NULL, origin, studyplot=NULL, barrier=NULL, funct="t", move=16, field=0, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, lcp.dens=FALSE, transp=0.5, export=FALSE){
   #if no dtm is provided
   if (is.null(dtm)==TRUE) {
     #get the elvation data using the elevatr's get_elev_raster() function, using the studyplot dataset (SpatialPolygonDataFrame)
@@ -116,23 +133,72 @@ movenetw <- function (dtm=NULL, origin, studyplot=NULL, funct="t", move=16, cogn
     dtm <- raster::crop(elev.data, studyplot)
   }
 
-  #create an empty list where to store the computed LCPs
+  #create an empty list to store the computed LCPs
   paths.netw <- vector(mode = "list", length = length(origin))
 
   message(paste0("Wait...processing ", length(origin)*(length(origin)-1), " LCPs..."))
 
+  #use the 'movecost' function to calculate the 'conductance' transitional layer to be used inside the
+  #loop that follows. The conductance layer is calculated because it will be used by the gdistance's shortestPath() function
+  #to calculate all the pairwise LCPs. Only one origin location suffices to calculate the conductance.
+  conductance.to.use <- movecost(dtm = dtm, origin = origin[1,], barrier=barrier, funct = funct, move = move, field=field, sl.crit = sl.crit, W = W, L = L, N = N, V = V, graph.out = FALSE)$conductance
+
   #set the progress bar
   pb <- txtProgressBar(min = 0, max = length(origin), style = 3)
 
   #loop through the origins and store the LCPs (per each origin) in the previously defined list
   for (i in 1:length(origin)) {
-    paths.netw[[i]] <- movecost(dtm = dtm, origin = origin[i,], destin = origin[-i,], funct = funct, move = move, sl.crit = sl.crit, W = W, L = L, N = N, V = V, graph.out = FALSE)$LCPs
+    paths.netw[[i]] <- gdistance::shortestPath(conductance.to.use, sp::coordinates(origin[i,]), sp::coordinates(origin[-i,]), output="SpatialLines")
     setTxtProgressBar(pb, i)
   }
 
+  #if a walking-time cost function has been selected...
+  if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="ug" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks" | funct=="ma"){
+    #...create two matrices, one for minutes, one for hours (note: the original conductance trans layer is in seconds)
+    cost.matrix.min <- gdistance::costDistance(conductance.to.use, sp::coordinates(origin)) / 60
+    cost.matrix.hr <- gdistance::costDistance(conductance.to.use, sp::coordinates(origin)) / 3600
+    cost.matrix <- NULL
+  } else {
+    #otherwise (i.e., if the cost function is not about time)
+    #set the two preceding cost-matrices to NULL, and return another cost matrix
+    cost.matrix.min <- NULL
+    cost.matrix.hr <- NULL
+    cost.matrix <- as.matrix(gdistance::costDistance(conductance.to.use, sp::coordinates(origin)))
+  }
+
   #merge the LCPs
   paths.netw.merged<- do.call(rbind, paths.netw)
 
+  #if either the cost matrix in minutes or in hours is NULL (i.e., if energy functions have been used)...
+  if(is.null(cost.matrix.min)==TRUE | is.null(cost.matrix.hr==TRUE)) {
+    #...use the cost.matrix object
+    #set the diagolnal to NA
+    diag(cost.matrix) <- NA
+    #calculate the minumum cost column-wise
+    min.index.col <- apply(cost.matrix, 2, which.min)
+  } else {
+    #if time functions have been used, do the same for the cost.matrix.min
+    diag(cost.matrix.min) <- NA
+    min.index.col <- apply(cost.matrix.min, 2, which.min)
+  }
+
+  #create an empty list to store the computed LCPs among neighboring locations
+  paths.netw.neigh <- vector(mode = "list", length = length(origin))
+
+  #set the progress bar
+  pb <- txtProgressBar(min = 0, max = length(origin), style = 3)
+
+  #loop through the origins, and calculate the LCP between each origin
+  #and its nearest neighbor, which is represented by the vector called min.index.col created previouly;
+  #the LCPs (per each origin) are stored in the previously defined list
+  for (i in 1:length(origin)) {
+    paths.netw.neigh[[i]] <- gdistance::shortestPath(conductance.to.use, sp::coordinates(origin[i,]), sp::coordinates(origin[min.index.col[i],]), output="SpatialLines")
+    setTxtProgressBar(pb, i)
+  }
+
+  #merge the LCPs between neigbhoring locations
+  paths.netw.neigh.merged <- do.call(rbind, paths.netw.neigh)
+
   #define different types of cost functions and set the appropriate text to be used for subsequent plotting
   if (funct=="t") {
     sub.title <- paste0("LCPs based on the Tobler's on-path hiking function \nterrain factor N=", N)
@@ -242,20 +308,23 @@ movenetw <- function (dtm=NULL, origin, studyplot=NULL, funct="t", move=16, cogn
     }
   }
 
+  if(funct=="h") {
+    sub.title <- paste0("LCPs based on the Hare's metabolic cost function \n cost in cal/km \n terrain factor N=", N)
+  }
+
+  if(funct=="e") {
+    sub.title <- paste0("LCPs based on the Eastman's cost function \n terrain factor N=", N)
+  }
+
   #produce the ingredients for the hillshade raster
   slope <- raster::terrain(dtm, opt = "slope")
   aspect <- raster::terrain(dtm, opt = "aspect")
   hill <- raster::hillShade(slope, aspect, angle = 45, direction = 0)
 
-  #conditionally set the layout in just one visualization
-  if(lcp.dens==TRUE & oneplot==TRUE){
-    m <- rbind(c(1,2))
-    layout(m)
-  }
-
+  #plots for the LCPs among all locations
   #plot the DTM
   raster::plot(dtm,
-               main="Network of least-cost paths among multiple origins",
+               main="Network of least-cost paths between multiple origins",
                sub=sub.title,
                cex.main=0.95,
                cex.sub=0.75,
@@ -311,7 +380,7 @@ movenetw <- function (dtm=NULL, origin, studyplot=NULL, funct="t", move=16, cogn
 
     #plot the DTM
     raster::plot(lcp.density.perc,
-                 main="Density of least-cost paths among multiple origins",
+                 main="Density of least-cost paths between multiple origins",
                  sub=sub.title,
                  cex.main=0.95,
                  cex.sub=0.75,
@@ -331,12 +400,45 @@ movenetw <- function (dtm=NULL, origin, studyplot=NULL, funct="t", move=16, cogn
                   add=TRUE)
   }
 
+  #plots for the LCPs among neighboring locations
+  #plot the DTM
+  raster::plot(dtm,
+               main="Network of least-cost paths between neighboring locations",
+               sub=sub.title,
+               cex.main=0.95,
+               cex.sub=0.75,
+               legend.lab="Elevation (masl)")
+
+  #plot the hillshade
+  raster::plot(hill,
+               col = grey(0:100/100),
+               legend = FALSE,
+               alpha=transp,
+               add=TRUE)
+
+  #add the path network
+  raster:: plot(paths.netw.neigh.merged,
+                add=TRUE)
+
+  #add the origin(s)
+  raster:: plot(origin,
+                pch=20,
+                col="red",
+                add=TRUE)
 
   #if export is TRUE, export the LCPs network as a shapefile, and the density rasters as geotiff
   if(export==TRUE){
-    rgdal::writeOGR(paths.netw.merged, ".", paste0("LCPs.netw.merged_", funct), driver="ESRI Shapefile")
+    #convert the merged LCPs network from SpatialLine to SpatialLineDataFrame via the 'SpatialLinesDataFrame()' function
+    #this is needed by 'writeOGR()'
+    paths.netw.merged.SPLDF <- sp::SpatialLinesDataFrame(paths.netw.merged, data.frame(id=1:length(paths.netw.merged)), match.ID = F)
+    paths.netw.neigh.merged.SPLDF <- sp::SpatialLinesDataFrame(paths.netw.neigh.merged, data.frame(id=1:length(paths.netw.neigh.merged)), match.ID = F)
+    #export relevant data
+    rgdal::writeOGR(paths.netw.merged.SPLDF, ".", paste0("LCPs.netw.merged_", funct), driver="ESRI Shapefile")
+    rgdal::writeOGR(paths.netw.neigh.merged.SPLDF, ".", paste0("LCPs.netw.neigh.merged_", funct), driver="ESRI Shapefile")
+    if(lcp.dens==TRUE){
     raster::writeRaster(pathcounts, paste0("LCPs_density_count_", funct), format="GTiff")
     raster::writeRaster(lcp.density.perc, paste0("LCPs_density_perc_", funct), format="GTiff")
+    }
   }
 
   #if no DTM was provided (i.e., if 'studyplot' is not NULL), export the downloaded DTM as a raster file
@@ -365,16 +467,16 @@ movenetw <- function (dtm=NULL, origin, studyplot=NULL, funct="t", move=16, cogn
     lcp.density.perc <- NULL
   }
 
-  #restore the original graphical device's settings if previously modified
-  if(lcp.dens==TRUE & oneplot==TRUE){
-    par(mfrow = c(1,1))
-  }
-
   results <- list("dtm"=dtm,
                   "LCPs.netw"=paths.netw,
                   "LCPs.netw.merged"=paths.netw.merged,
+                  "LCPs.netw.neigh"=paths.netw.neigh,
+                  "LCPs.netw.neigh.merged"=paths.netw.neigh.merged,
                   "LCPs.density.count"=pathcounts,
-                  "LCPs.density.perc"=lcp.density.perc)
+                  "LCPs.density.perc"=lcp.density.perc,
+                  "cost.matrix.min"=cost.matrix.min,
+                  "cost.matrix.hrs"=cost.matrix.hr,
+                  "cost.matrix"=cost.matrix)
 
   return(results)
 }
